
/* Terminality - a portable terminal handling library
 * Copyright (C) 1999-2001, Emil Mikulic.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: extra.h,v 1.18 2001/04/23 10:56:09 darkmoon Exp $ */

/* Project:     Terminality
 * File:	extra.h
 * Author:      Emil Mikulic
 * Description: Provide interface for extra functions
 */

#ifndef _extra_h_
#define _extra_h_

#include "tn.h"
#include "xmem.h"

#ifdef __cplusplus
extern "C" {
#endif

/* Box functions */
void drawbox(int x1, int y1, int x2, int y2);	/* Simple box */
void box_3d(int x1, int y1, int x2, int y2, color basecolor,
	color lite, color dark);		/* 3d box */

/* in/out 3d boxes */
#define drawbox_in(x1,y1,x2,y2,c) \
	box_3d(x1,y1,x2,y2,c,Black,(color)(c+8))

#define drawbox_out(x1,y1,x2,y2,c) \
	box_3d(x1,y1,x2,y2,c,(color)(c+8),Black)

/* Text functions */
int printc(char *format, ...);
int writexy(int x, int y, char *format, ...);
int center(int y, char *format, ...);

/* Other stuff */
void fillscreen(color f, color b, chtype c);
void textviewer(int x, int y, int w, int h, char *ttbuf);

#ifdef __cplusplus
}
#endif

#endif

/*
 * $Log: extra.h,v $
 * Revision 1.18  2001/04/23 10:56:09  darkmoon
 * (Volker) Added a text-viewer function
 *
 * Revision 1.17  2001/02/20 11:23:04  darkmoon
 * Minor cosmetic changes
 *
 * Revision 1.16  2001/02/18 05:50:18  darkmoon
 * LGPL'd
 *
 * Revision 1.15  2001/01/12 15:40:14  darkmoon
 * Took out stdarg.h, put it in extra.c
 *
 * Revision 1.14  2001/01/07 09:58:43  darkmoon
 * Polished up for Terminality 1.6 release
 *
 * Revision 1.13  2001/01/05 09:54:33  darkmoon
 * Added printc()
 *
 * Revision 1.12  2000/09/04 07:36:17  darkmoon
 * Polished up for Terminality 1.4 release
 *
 * Revision 1.11  1999/11/22 09:30:12  darkmoon
 * Added short disclaimer and copyright notice to beginning of file.
 *
 * Revision 1.10  1999/11/22 04:34:18  darkmoon
 * Changed fillscreen() to take color parameters of type color
 *
 * Revision 1.9  1999/11/22 04:19:17  darkmoon
 * Made box_3d take color parameters of type color instead of int
 * Changed drawbox_in and drawbox_out to follow this change.
 *
 * Revision 1.8  1999/11/20 09:57:22  darkmoon
 * Moved revision log to end of file
 *
 * Revision 1.7  1999/05/18 08:29:17  darkmoon
 * Added `extern "C" {' thing
 * Killed textbox prototypes
 *
 * Revision 1.6  1999/03/06 07:24:17  darkmoon
 * Renamed to Terminality
 * All files were brought up-to-standard (except the W32 stuff, hehe) for
 * the first release of Terminality (v0.2 build 6)
 *
 * Revision 1.5  1999/01/11 04:08:34  darkmoon
 * Added Volker's modifications.
 *
 * Revision 1.4  1998/12/09 06:25:52  darkmoon
 * Added textbox()
 *
 * Revision 1.3  1998/12/07 10:10:16  darkmoon
 * Added center() and writexy() routines.
 *
 * Revision 1.2  1998/12/07 10:00:09  darkmoon
 * Shuffling 3D-box stuff
 *
 * Revision 1.1  1998/12/07 09:50:03  darkmoon
 * Renamed box.* to extra.*
 *
 * Revision 1.1  1998/12/02 10:44:17  darkmoon
 * Initial revision of box drawing code.
 *
 */

