
/* Terminality - a portable terminal handling library
 * Copyright (C) 1999-2001, Emil Mikulic.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: keyhndl.h,v 1.6 2001/09/05 08:51:55 darkmoon Exp $ */

/* Project:     Terminality
 * File:	keyhndl.h
 * Author:      Michal Safranek
 * Description: Keyboard handler
 */

#ifndef __KEYHNDL_H__
#define __KEYHNDL_H__

#include <tn.h>
#include <list.h>
#include <string.h>
#include <assert.h>

/*
 *
 * Please, see note about key binding in gui.h ....
 *
 */


#ifdef __cplusplus
extern "C" {
#endif

/* global keys */
extern tn_list *handled_keys;

/* key struct */
typedef struct {
	key name;
	int (*fce)(key, element_type, void *);
} key_struct;

/* Returns position # in list by key, -1 if not found */
int real_get_key_position(tn_list *v, key k);

/* Registers key into v */
int real_register_key(tn_list **v, key k, key (*fce)(key, element_type, void *),
		int overwrite);

/* Unregisters key */
int real_unregister_key(tn_list **v, key k);

/* Set default keys */
void default_keys(void);

/* Delete all keys */
void real_delete_keys(tn_list **v);

/* Handles pressed key (from element type=type, address=ptr) */
int real_handle_key(tn_list **v, key k, element_type type, void *ptr);

/* Here are 'global' defs - definitions for 'global' keys */
#define get_key_position(k)		real_get_key_position(handled_keys, k)
#define register_key(k, f, o)	real_register_key(&handled_keys, k, f, o)
#define unregister_key(k)		real_unregister_key(&handled_keys, k)
#define delete_keys()			real_delete_keys(&handled_keys)
#define handle_key(k, t, p)		real_handle_key(&handled_keys, k, t, p)
	

#ifdef __cplusplus
}
#endif

#endif

/*
 * $Log: keyhndl.h,v $
 * Revision 1.6  2001/09/05 08:51:55  darkmoon
 * (Michal) Added local keyhandlers
 * Global keyhandler is now called before builtin.
 *
 * Revision 1.5  2001/02/20 11:23:04  darkmoon
 * Minor cosmetic changes
 *
 * Revision 1.4  2001/02/18 05:50:18  darkmoon
 * LGPL'd
 *
 * Revision 1.3  2001/02/16 02:41:40  darkmoon
 * Changed all instances of the list to tn_list
 *
 * Revision 1.2  2001/01/05 17:16:00  darkmoon
 * Make list.h include global
 *
 * Revision 1.1  2001/01/05 15:05:57  darkmoon
 * (Michal) Initial revision
 *
 */

