
/* Terminality - a portable terminal handling library
 * Copyright (C) 1999-2001, Emil Mikulic.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: register.h,v 1.4 2001/02/20 11:23:04 darkmoon Exp $ */

/* Project:     Terminality
 * File:	register.h
 * Author:      Michal Safranek
 * Description: Element register
 */

#ifndef __REGISTER_H__
#define __REGISTER_H__

#include "tn.h"
#include "list.h"

#ifdef __cplusplus
extern "C" {
#endif



#ifdef __REGISTER_INTERNAL__

/* Element register list - here are elements stored */
extern tn_list *register_list;

/* Max elem id now */
extern int register_maxid;



/* Struct stored in reg. list */
typedef struct {
	element_type type;
	int id;
	void *elem;
} register_elem;



#endif



/* Add element to register */
int register_add(element_type type, void *ptr);

/* Del element from register */
int register_del(int id);

/* Free whole register */
void register_free(void);

/* Call-back function for all elements */
void register_callback(void (*fce)(element_type, void *));

#ifdef __cplusplus
}
#endif

#endif

/*
 * $Log: register.h,v $
 * Revision 1.4  2001/02/20 11:23:04  darkmoon
 * Minor cosmetic changes
 *
 * Revision 1.3  2001/02/18 05:50:18  darkmoon
 * LGPL'd
 *
 * Revision 1.2  2001/02/16 02:41:40  darkmoon
 * Changed all instances of the list to tn_list
 *
 * Revision 1.1  2001/01/05 15:50:51  darkmoon
 * (Michal) Initial revision
 *
 */

