
/* Terminality - a portable terminal handling library
 * Copyright (C) 1999-2001, Emil Mikulic.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: tn_nc.h,v 1.14 2001/09/05 02:33:00 darkmoon Exp $ */

/* Project:     Terminality
 * File:	tn_nc.h
 * Description: Provides ncurses interface changes
 */

#ifndef _tn_nc_h_
#define _tn_nc_h_

#define TN_H_IMPLEMENTED

/* avoid printw() definition clash */
#define printw ncurses_printw

/* (n/pd)curses includes */
#ifdef __DJGPP__
#include <curses.h>
#else
#include <ncurses.h>
#endif

/* get rid of it now */
#undef printw

/* ncurses specifics */
int initcolor(void);

/* Special character macro */
#define CTRLCHAR (1 << 22)
#define _c(x) ((x) | CTRLCHAR)

/* Special character set */
#define HLINE	ACS_HLINE
#define VLINE	ACS_VLINE
#define CROSS	ACS_PLUS
#define C_UL	ACS_ULCORNER
#define C_UR	ACS_URCORNER
#define C_LL	ACS_LLCORNER
#define C_LR	ACS_LRCORNER
#define BLOCK_1	ACS_BOARD
#define BLOCK_2	ACS_CKBOARD
#define BLOCK_3 _c(178)
#define BLOCK_4 ACS_BLOCK
#define TEE_L	ACS_RTEE
#define TEE_R	ACS_LTEE
#define TEE_U	ACS_BTEE
#define TEE_D	ACS_TTEE
#define ARROW_L	ACS_LARROW
#define ARROW_R	ACS_RARROW
#define ARROW_U	ACS_UARROW
#define ARROW_D	ACS_DARROW

/* Console size */
#define CON_COLS COLS
#define CON_ROWS LINES

#define key int
#undef KEY_ENTER
#define KEY_ENTER '\r'
#define KEY_INS KEY_IC
#define KEY_DEL KEY_DC
#define KEY_ESC 27
#define KEY_PGUP KEY_PPAGE
#define KEY_PGDOWN KEY_NPAGE
#define KEY_TAB '\t'
#ifdef __DJGPP__
#undef KEY_BACKSPACE
#define KEY_BACKSPACE '\b'
#endif
#define KEY_REDRAW 12
#define KEY_NOTHING 32101
#define KEY_SUPERVISE (KEY_NOTHING + 1) /* Virtual key */


/* Kill clear and erase so <vector> doesn't choke on them */
#undef clear
#undef erase

#endif

/*
 * $Log: tn_nc.h,v $
 * Revision 1.14  2001/09/05 02:33:00  darkmoon
 * (Michal) Added KEY_SUPERVISE
 *
 * Revision 1.13  2001/04/23 10:57:53  darkmoon
 * (Volker) Added KEY_INS
 *
 * Revision 1.12  2001/02/20 11:23:04  darkmoon
 * Minor cosmetic changes
 *
 * Revision 1.11  2001/02/18 05:50:18  darkmoon
 * LGPL'd
 *
 * Revision 1.10  2001/01/07 09:58:43  darkmoon
 * Polished up for Terminality 1.6 release
 *
 * Revision 1.9  2001/01/05 17:16:30  darkmoon
 * Merged in Michal's changes (lots of)
 *
 * Revision 1.8  2000/09/20 09:34:19  darkmoon
 * Got rid of my old e-mail address.
 *
 * Revision 1.7  2000/08/06 07:17:04  darkmoon
 * Ported to work with DJGPP/pdcurses
 *
 * Revision 1.6  2000/04/11 06:13:19  darkmoon
 * Changed CTRLCHAR to a bit-shifted value
 *
 * Revision 1.5  1999/11/22 09:30:12  darkmoon
 * Added short disclaimer and copyright notice to beginning of file.
 *
 * Revision 1.4  1999/11/22 09:05:59  darkmoon
 * Added _c(x) macro
 *
 * Revision 1.3  1999/11/20 10:10:20  darkmoon
 * Moved revision log to end of file
 * Added a define to get around printw() redefinition
 * Killed AUTO_UPDATE (rust in pieces)
 *
 * Revision 1.2  1999/05/18 08:32:02  darkmoon
 * Undefined clear and erase so they don't clash with the C++ vector code
 * CON_COLS and CON_ROWS no longer refer to sizex()/sizey()
 * Added KEY_ESC, KEY_PGUP, KEY_PGDOWN, KEY_TAB
 *
 * Revision 1.1  1999/03/06 07:24:17  darkmoon
 * Renamed to Terminality
 * All files were brought up-to-standard (except the W32 stuff, hehe) for
 * the first release of Terminality (v0.2 build 6)
 *
 * Revision 1.13  1999/02/21 05:14:35  darkmoon
 * Fixed BLOCK chars
 *
 * Revision 1.12  1999/01/16 02:54:31  darkmoon
 * That's KEY_DEL, not KEY_BACKSPACE
 *
 * Revision 1.11  1999/01/16 02:36:20  darkmoon
 * Added KEY_DEL capability
 *
 * Revision 1.10  1999/01/11 05:08:50  darkmoon
 * Minor change.
 *
 * Revision 1.9  1998/12/09 07:03:59  darkmoon
 * Added console size defines
 * Fixed KEY_ENTER
 *
 * Revision 1.8  1998/12/02 10:43:55  darkmoon
 * Flipped BLOCK_1 and BLOCK_2
 *
 * Revision 1.7  1998/12/02 10:08:26  darkmoon
 * Added special characters
 *
 * Revision 1.6  1998/12/02 09:40:33  darkmoon
 * Removed COLOR[][] definition
 *
 * Revision 1.5  1998/12/02 09:18:50  darkmoon
 * Color-specific changes.
 *
 * Revision 1.4  1998/12/01 10:49:12  darkmoon
 * Added AUTO_UPDATE handling
 *
 * Revision 1.3  1998/12/01 10:40:32  darkmoon
 * Assumed that there are 8 colors.
 *
 * Revision 1.2  1998/12/01 10:33:41  darkmoon
 * Fixed header and definitions
 *
 * Revision 1.1.1.1  1998/12/01 10:15:51  darkmoon
 * Setting up
 *
 */

