
/* Terminality - a portable terminal handling library
 * Copyright (C) 1999-2001, Emil Mikulic.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: tn_w32.h,v 1.15 2001/10/19 13:42:49 darkmoon Exp $ */

/* File:	tn_w32.h
 * Project:     Terminality
 * Author:      Emil Mikulic
 * Description: Provide some help for the Win32 implementation
 */

/* Terminality
 * Wrapper around Win32 console. This interface
 * works on a Win32 platform (NT, 95, 98) and should work
 * with Microsoft Visual C++ 5.0 or Cygnus CygWin32 B19 */

/* Developer Studio kiddies: Set your tab stops to 8 or 
 * there's gonna be trouble!
 */

#ifndef _tn_w32_h_
#define _tn_w32_h_
#define TN_H_IMPLEMENTED

/* confuse Borland C */
#define textcolor	_textcolor
#define textbackground	_textbackground
#define textattr	_textattr

/* --- platform-dependent include files */
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <stdarg.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <conio.h>

/* unconfuse Borland C */
#undef textcolor
#undef textbackground
#undef textattr

/* --- color bitmasks --- */
#define FG_MASK		240 /* 11110000 */
#define BG_MASK		15  /* 00001111 */
#define TEXT_BOLD	8   /* 00001000 */
#define BG_BITS		4

/* some debugging */
#ifdef NDEBUG
#define PERR(x) x
#else
#define PERR(x) if (!(x)) conserr(__FILE__, __LINE__)
#endif

#ifdef __cplusplus
extern "C" {
#endif

/* Console size */
extern int CON_COLS, CON_ROWS;

/* Win32 Specifics */
void conserr(char *, int);

#ifdef __cplusplus
};
#endif

/* Special character set */
#define _c(x) ((char)(x))

#define HLINE	_c(196)
#define VLINE	_c(179)
#define CROSS	_c(197)
#define C_UL	_c(218)
#define C_UR	_c(191)
#define C_LL	_c(192)
#define C_LR	_c(217)
#define BLOCK_1	_c(176)
#define BLOCK_2	_c(177)
#define BLOCK_3 _c(178)
#define BLOCK_4 _c(219)
#define TEE_L	_c(180)
#define TEE_R	_c(195)
#define TEE_U	_c(193)
#define TEE_D	_c(194)
#define ARROW_L	_c(27)
#define ARROW_R	_c(26)
#define ARROW_U	_c(24)
#define ARROW_D	_c(25)

/* Keys */
#define key		int
#define chtype		unsigned char
#define KEY_BACKSPACE	8 /*'\b'*/
#define KEY_ENTER	'\r'
#define KEY_TAB		'\t'
#define KEY_ESC		27

#define KEY_REDRAW 12
#define KEY_NOTHING 32101
#define KEY_SUPERVISE (KEY_NOTHING + 1) /* Virtual key */

#ifdef __BORLANDC__
#define CONTROL_KEY	0
#else
#define CONTROL_KEY	(224 << 8)
#endif
#define KEY_UP		(CONTROL_KEY | 72)
#define KEY_DOWN	(CONTROL_KEY | 80)
#define KEY_RIGHT	(CONTROL_KEY | 77)
#define KEY_LEFT	(CONTROL_KEY | 75)
#define KEY_INS		(CONTROL_KEY | 82)
#define KEY_DEL		(CONTROL_KEY | 83)
#define KEY_PGUP	(CONTROL_KEY | 73)
#define KEY_PGDOWN	(CONTROL_KEY | 81)
#define KEY_HOME	(CONTROL_KEY | 71)
#define KEY_END		(CONTROL_KEY | 79)

#endif



/*
 * $Log: tn_w32.h,v $
 * Revision 1.15  2001/10/19 13:42:49  darkmoon
 * Minor cosmetic fixes
 *
 * Revision 1.14  2001/10/19 13:37:11  darkmoon
 * Preliminary BCC support
 *
 * Revision 1.13  2001/09/05 02:33:25  darkmoon
 * (Michal) Added KEY_SUPERVISE
 *
 * Revision 1.12  2001/04/23 10:59:13  darkmoon
 * (Volker) Added KEY_INS
 *
 * Revision 1.11  2001/02/20 11:23:04  darkmoon
 * Minor cosmetic changes
 *
 * Revision 1.10  2001/02/18 05:50:18  darkmoon
 * LGPL'd
 *
 * Revision 1.9  2001/01/07 09:58:43  darkmoon
 * Polished up for Terminality 1.6 release
 *
 * Revision 1.8  2001/01/05 17:16:58  darkmoon
 * Added KEY_REDRAW and KEY_NOTHING (to reflect Michal's changes to tn_nc.h)
 *
 * Revision 1.7  2000/09/04 07:36:17  darkmoon
 * Polished up for Terminality 1.4 release
 *
 * Revision 1.6  1999/11/22 22:24:40  darkmoon
 * Changed chtype to unsigned char
 *
 * Revision 1.5  1999/11/22 09:30:12  darkmoon
 * Added short disclaimer and copyright notice to beginning of file.
 *
 * Revision 1.4  1999/11/20 10:11:34  darkmoon
 * Moved revision log to end of file
 * Removed printw() definition because it's now in tn.h
 *
 * Revision 1.3  1999/05/18 08:34:07  darkmoon
 * Removed sizex()/sizey() in favor of CON_COLS/CON_ROWS
 * Redefined and added keys
 *
 * Revision 1.2  1999/03/20 10:58:46  darkmoon
 * Fixed error handling (PERR)
 * readkey() now recognises DEL and arrow keys
 * Added low/norm/highvideo()
 * Fixed block characters
 * Added readkey() keys
 *
 * Revision 1.1  1999/03/06 07:24:17  darkmoon
 * Renamed to Terminality
 * All files were brought up-to-standard (except the W32 stuff, hehe) for
 * the first release of Terminality (v0.2 build 6)
 *
 * Revision 0.2  1998/12/09 07:04:29  darkmoon
 * General compatibility fixes.
 *
 * Revision 0.1  1998/12/09 06:26:09  darkmoon
 * Initial revision
 *
 */

