
/* Terminality - a portable terminal handling library
 * Copyright (C) 1999-2001, Emil Mikulic.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: xmem.h,v 1.4 2001/02/20 11:23:04 darkmoon Exp $ */

/* Project:     Terminality
 * File:	xmem.h
 * Author:      Michal Safranek, Emil Mikulic
 * Description: Safe memory functions
 */



#ifndef __XMEM_H__
#define __XMEM_H__

#include <stdio.h>
#include <stdlib.h>

#ifdef __cplusplus
extern "C" {
#endif



/* functions will print debug messages if xmem_want_debug != 0 */
extern int xmem_want_debug;

/* debug messages go to... */
#ifndef xmem_debug_fd
#define xmem_debug_fd stderr
#endif



/* allocates memory || dies when it goes OOM */
void *xmalloc(size_t bytes);

/* reallocates memory || dies when it goes OOM */
void *xrealloc(void *ptr, size_t bytes);

/* frees memory */
void xfree(void *ptr);



#ifdef __cplusplus
}
#endif

#endif



/*
 * $Log: xmem.h,v $
 * Revision 1.4  2001/02/20 11:23:04  darkmoon
 * Minor cosmetic changes
 *
 * Revision 1.3  2001/02/18 05:50:18  darkmoon
 * LGPL'd
 *
 * Revision 1.2  2001/01/05 17:17:48  darkmoon
 * Gave up on trying to set an xfree'd pointer to NULL
 *
 * Revision 1.1  2001/01/05 15:33:26  darkmoon
 * (Michal) Initial revision + a few little changes from Emil
 *
 */

